#ifndef ATL_dGetNB_geqrf

/*
 * NB selection for GEQRF: Side='RIGHT', Uplo='UPPER'
 * M : 25,480,990,2010
 * N : 25,480,990,2010
 * NB : 5,30,30,30
 */
#define ATL_dGetNB_geqrf(n_, nb_) \
{ \
   if ((n_) < 252) (nb_) = 5; \
   else (nb_) = 30; \
}


#endif    /* end ifndef ATL_dGetNB_geqrf */
